Class: Aws::KMS::Types::CustomKeyStoreHasCMKsException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

The request was rejected because the custom key store contains KMS keys. After verifying that you do not need to use the KMS keys, use the ScheduleKeyDeletion operation to delete the KMS keys. After they are deleted, you can delete the custom key store.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1271
1272
1273
1274
1275
# File 'lib/aws-sdk-kms/types.rb', line 1271

class CustomKeyStoreHasCMKsException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end