Class: Aws::KMS::Types::DecryptRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::DecryptRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ciphertext_blob ⇒ String
Ciphertext to be decrypted.
-
#dry_run ⇒ Boolean
Checks if your request will succeed.
-
#dry_run_modifiers ⇒ Array<String>
Specifies the modifiers to apply to the dry run operation.
-
#encryption_algorithm ⇒ String
Specifies the encryption algorithm that will be used to decrypt the ciphertext.
-
#encryption_context ⇒ Hash<String,String>
Specifies the encryption context to use when decrypting the data.
-
#grant_tokens ⇒ Array<String>
A list of grant tokens.
-
#key_id ⇒ String
Specifies the KMS key that KMS uses to decrypt the ciphertext.
-
#recipient ⇒ Types::RecipientInfo
A signed [attestation document] from an Amazon Web Services Nitro enclave or NitroTPM, and the encryption algorithm to use with the public key in the attestation document.
Instance Attribute Details
#ciphertext_blob ⇒ String
Ciphertext to be decrypted. The blob includes metadata.
This parameter is required in all cases except when ‘DryRun` is `true` and `DryRunModifiers` is set to `IGNORE_CIPHERTEXT`.
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Checks if your request will succeed. ‘DryRun` is an optional parameter.
To learn more about how to use this parameter, see [Testing your permissions] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/testing-permissions.html
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |
#dry_run_modifiers ⇒ Array<String>
Specifies the modifiers to apply to the dry run operation. ‘DryRunModifiers` is an optional parameter that only applies when `DryRun` is set to `true`.
When set to ‘IGNORE_CIPHERTEXT`, KMS performs only authorization validation without ciphertext validation. This allows you to test permissions without requiring a valid ciphertext blob.
To learn more about how to use this parameter, see [Testing your permissions] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/testing-permissions.html
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |
#encryption_algorithm ⇒ String
Specifies the encryption algorithm that will be used to decrypt the ciphertext. Specify the same algorithm that was used to encrypt the data. If you specify a different algorithm, the ‘Decrypt` operation fails.
This parameter is required only when the ciphertext was encrypted under an asymmetric KMS key. The default value, ‘SYMMETRIC_DEFAULT`, represents the only supported algorithm that is valid for symmetric encryption KMS keys.
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |
#encryption_context ⇒ Hash<String,String>
Specifies the encryption context to use when decrypting the data. An encryption context is valid only for [cryptographic operations] with a symmetric encryption KMS key. The standard asymmetric encryption algorithms and HMAC algorithms that KMS uses do not support an encryption context.
An *encryption context* is a collection of non-secret key-value pairs that represent additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is supported only on operations with symmetric encryption KMS keys. On operations with symmetric encryption KMS keys, an encryption context is optional, but it is strongly recommended.
For more information, see [Encryption context] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/kms-cryptography.html#cryptographic-operations [2]: docs.aws.amazon.com/kms/latest/developerguide/encrypt_context.html
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |
#grant_tokens ⇒ Array<String>
A list of grant tokens.
Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved *eventual consistency*. For more information, see [Grant token] and [Using a grant token] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/grants.html#grant_token [2]: docs.aws.amazon.com/kms/latest/developerguide/using-grant-token.html
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
Specifies the KMS key that KMS uses to decrypt the ciphertext.
Enter a key ID of the KMS key that was used to encrypt the ciphertext. If you identify a different KMS key, the ‘Decrypt` operation throws an `IncorrectKeyException`.
This parameter is required only when the ciphertext was encrypted under an asymmetric KMS key or when ‘DryRun` is `true` and `DryRunModifiers` is set to `IGNORE_CIPHERTEXT`. If you used a symmetric encryption KMS key, KMS can get the KMS key from metadata that it adds to the symmetric ciphertext blob. However, it is always recommended as a best practice. This practice ensures that you use the KMS key that you intend.
To specify a KMS key, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with ‘“alias/”`. To specify a KMS key in a different Amazon Web Services account, you should use the key ARN or alias ARN.
For example:
-
Key ID: ‘1234abcd-12ab-34cd-56ef-1234567890ab`
-
Key ARN: ‘arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab`
-
Alias name: ‘alias/ExampleAlias`
-
Alias ARN: ‘arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias`
To get the key ID and key ARN for a KMS key, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |
#recipient ⇒ Types::RecipientInfo
A signed [attestation document] from an Amazon Web Services Nitro enclave or NitroTPM, and the encryption algorithm to use with the public key in the attestation document. The only valid encryption algorithm is ‘RSAES_OAEP_SHA_256`.
This parameter supports the [Amazon Web Services Nitro Enclaves SDK] or any Amazon Web Services SDK for Amazon Web Services Nitro Enclaves. It supports any Amazon Web Services SDK for Amazon Web Services NitroTPM.
When you use this parameter, instead of returning the plaintext data, KMS encrypts the plaintext data with the public key in the attestation document, and returns the resulting ciphertext in the ‘CiphertextForRecipient` field in the response. This ciphertext can be decrypted only with the private key in the attested environment. The `Plaintext` field in the response is null or empty.
For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see
- Cryptographic attestation support in KMS][3
-
in the *Key Management
Service Developer Guide*.
[1]: docs.aws.amazon.com/enclaves/latest/user/nitro-enclave-concepts.html#term-attestdoc [2]: docs.aws.amazon.com/enclaves/latest/user/developing-applications.html#sdk [3]: docs.aws.amazon.com/kms/latest/developerguide/cryptographic-attestation.html
1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 |
# File 'lib/aws-sdk-kms/types.rb', line 1715 class DecryptRequest < Struct.new( :ciphertext_blob, :encryption_context, :grant_tokens, :key_id, :encryption_algorithm, :recipient, :dry_run, :dry_run_modifiers) SENSITIVE = [] include Aws::Structure end |