Class: Aws::KMS::Types::DescribeCustomKeyStoresRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::DescribeCustomKeyStoresRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_key_store_id ⇒ String
Gets only information about the specified custom key store.
-
#custom_key_store_name ⇒ String
Gets only information about the specified custom key store.
-
#limit ⇒ Integer
Use this parameter to specify the maximum number of items to return.
-
#marker ⇒ String
Use this parameter in a subsequent request after you receive a response with truncated results.
Instance Attribute Details
#custom_key_store_id ⇒ String
Gets only information about the specified custom key store. Enter the key store ID.
By default, this operation gets information about all custom key stores in the account and Region. To limit the output to a particular custom key store, provide either the ‘CustomKeyStoreId` or `CustomKeyStoreName` parameter, but not both.
2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-kms/types.rb', line 2169 class DescribeCustomKeyStoresRequest < Struct.new( :custom_key_store_id, :custom_key_store_name, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#custom_key_store_name ⇒ String
Gets only information about the specified custom key store. Enter the friendly name of the custom key store.
By default, this operation gets information about all custom key stores in the account and Region. To limit the output to a particular custom key store, provide either the ‘CustomKeyStoreId` or `CustomKeyStoreName` parameter, but not both.
2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-kms/types.rb', line 2169 class DescribeCustomKeyStoresRequest < Struct.new( :custom_key_store_id, :custom_key_store_name, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
Use this parameter to specify the maximum number of items to return. When this value is present, KMS does not return more than the specified number of items, but it might return fewer.
2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-kms/types.rb', line 2169 class DescribeCustomKeyStoresRequest < Struct.new( :custom_key_store_id, :custom_key_store_name, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of ‘NextMarker` from the truncated response you just received.
2169 2170 2171 2172 2173 2174 2175 2176 |
# File 'lib/aws-sdk-kms/types.rb', line 2169 class DescribeCustomKeyStoresRequest < Struct.new( :custom_key_store_id, :custom_key_store_name, :limit, :marker) SENSITIVE = [] include Aws::Structure end |