Class: Aws::KMS::Types::GenerateRandomResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:plaintext]

Instance Attribute Summary collapse

Instance Attribute Details

#ciphertext_for_recipientString

The plaintext random bytes encrypted with the public key from the attestation document. This ciphertext can be decrypted only by using a private key from the attested environment.

This field is included in the response only when the Recipient parameter in the request includes a valid attestation document from an Amazon Web Services Nitro enclave or NitroTPM. For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see [Cryptographic attestation support in KMS] in the *Key Management Service Developer Guide*.

[1]: docs.aws.amazon.com/kms/latest/developerguide/cryptographic-attestation.html

Returns:

  • (String)


3421
3422
3423
3424
3425
3426
# File 'lib/aws-sdk-kms/types.rb', line 3421

class GenerateRandomResponse < Struct.new(
  :plaintext,
  :ciphertext_for_recipient)
  SENSITIVE = [:plaintext]
  include Aws::Structure
end

#plaintextString

The random byte string. When you use the HTTP API or the Amazon Web Services CLI, the value is Base64-encoded. Otherwise, it is not Base64-encoded.

If the response includes the CiphertextForRecipient field, the Plaintext field is null or empty.

Returns:

  • (String)


3421
3422
3423
3424
3425
3426
# File 'lib/aws-sdk-kms/types.rb', line 3421

class GenerateRandomResponse < Struct.new(
  :plaintext,
  :ciphertext_for_recipient)
  SENSITIVE = [:plaintext]
  include Aws::Structure
end