Class: Aws::KMS::Types::GetKeyLastUsageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::GetKeyLastUsageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_creation_date ⇒ Time
The date and time when the KMS key was created.
-
#key_id ⇒ String
The globally unique identifier for the KMS key.
-
#key_last_usage ⇒ Types::KeyLastUsageData
Contains usage information about the last time the KMS key was used for a successful cryptographic operation.
-
#tracking_start_date ⇒ Time
The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.
Instance Attribute Details
#key_creation_date ⇒ Time
The date and time when the KMS key was created.
3527 3528 3529 3530 3531 3532 3533 3534 |
# File 'lib/aws-sdk-kms/types.rb', line 3527 class GetKeyLastUsageResponse < Struct.new( :key_id, :key_last_usage, :tracking_start_date, :key_creation_date) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The globally unique identifier for the KMS key.
3527 3528 3529 3530 3531 3532 3533 3534 |
# File 'lib/aws-sdk-kms/types.rb', line 3527 class GetKeyLastUsageResponse < Struct.new( :key_id, :key_last_usage, :tracking_start_date, :key_creation_date) SENSITIVE = [] include Aws::Structure end |
#key_last_usage ⇒ Types::KeyLastUsageData
Contains usage information about the last time the KMS key was used for a successful cryptographic operation. If the key has not been used since tracking began, this response element is empty.
3527 3528 3529 3530 3531 3532 3533 3534 |
# File 'lib/aws-sdk-kms/types.rb', line 3527 class GetKeyLastUsageResponse < Struct.new( :key_id, :key_last_usage, :tracking_start_date, :key_creation_date) SENSITIVE = [] include Aws::Structure end |
#tracking_start_date ⇒ Time
The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.
3527 3528 3529 3530 3531 3532 3533 3534 |
# File 'lib/aws-sdk-kms/types.rb', line 3527 class GetKeyLastUsageResponse < Struct.new( :key_id, :key_last_usage, :tracking_start_date, :key_creation_date) SENSITIVE = [] include Aws::Structure end |