Class: Aws::KMS::Types::GetParametersForImportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::GetParametersForImportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:public_key]
Instance Attribute Summary collapse
-
#import_token ⇒ String
The import token to send in a subsequent ImportKeyMaterial request.
-
#key_id ⇒ String
The Amazon Resource Name ([key ARN]) of the KMS key to use in a subsequent ImportKeyMaterial request.
-
#parameters_valid_to ⇒ Time
The time at which the import token and public key are no longer valid.
-
#public_key ⇒ String
The public key to use to encrypt the key material before importing it with ImportKeyMaterial.
Instance Attribute Details
#import_token ⇒ String
The import token to send in a subsequent ImportKeyMaterial request.
3657 3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/aws-sdk-kms/types.rb', line 3657 class GetParametersForImportResponse < Struct.new( :key_id, :import_token, :public_key, :parameters_valid_to) SENSITIVE = [:public_key] include Aws::Structure end |
#key_id ⇒ String
The Amazon Resource Name ([key ARN]) of the KMS key to use in a subsequent ImportKeyMaterial request. This is the same KMS key specified in the GetParametersForImport request.
[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-ARN
3657 3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/aws-sdk-kms/types.rb', line 3657 class GetParametersForImportResponse < Struct.new( :key_id, :import_token, :public_key, :parameters_valid_to) SENSITIVE = [:public_key] include Aws::Structure end |
#parameters_valid_to ⇒ Time
The time at which the import token and public key are no longer valid. After this time, you cannot use them to make an ImportKeyMaterial request and you must send another GetParametersForImport request to get new ones.
3657 3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/aws-sdk-kms/types.rb', line 3657 class GetParametersForImportResponse < Struct.new( :key_id, :import_token, :public_key, :parameters_valid_to) SENSITIVE = [:public_key] include Aws::Structure end |
#public_key ⇒ String
The public key to use to encrypt the key material before importing it with ImportKeyMaterial.
3657 3658 3659 3660 3661 3662 3663 3664 |
# File 'lib/aws-sdk-kms/types.rb', line 3657 class GetParametersForImportResponse < Struct.new( :key_id, :import_token, :public_key, :parameters_valid_to) SENSITIVE = [:public_key] include Aws::Structure end |