Class: Aws::KMS::Types::GrantConstraints

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Use this structure to allow [cryptographic operations] in the grant only when the operation request meets the specified constraints.

KMS supports the following grant constraints:

  • ‘EncryptionContextEquals` and `EncryptionContextSubset` — These encryption context constraints apply only to cryptographic operations that support an encryption context, that is, all cryptographic operations with a symmetric KMS key. Encryption context grant constraints are not applied to operations that do not support an encryption context, such as cryptographic operations with asymmetric KMS keys and management operations, such as DescribeKey or RetireGrant.

    In a cryptographic operation, the encryption context in the decryption operation must be an exact, case-sensitive match for the keys and values in the encryption context of the encryption operation. Only the order of the pairs can vary.

    However, in a grant constraint, the key in each key-value pair is
    

    not case sensitive, but the value is case sensitive.

    To avoid confusion, do not use multiple encryption context pairs
    

    that differ only by case. To require a fully case-sensitive encryption context, use the ‘kms:EncryptionContext:` and `kms:EncryptionContextKeys` conditions in an IAM or key policy. For details, see [kms:EncryptionContext:context-key] in the Key Management Service Developer Guide .

  • ‘SourceArn` — This grant constraint allows the permissions in the grant only when the request is made on behalf of a specific Amazon Web Services resource, identified by its [Amazon Resource Name (ARN)]. This is effectively the same as having the

    aws:SourceArn][4

    global condition key in the grant. The SourceArn

    constraint is supported on grants for all types of KMS keys and can also be applied to the DescribeKey operation when specified in the request. However, it does not apply to RetireGrant operation.

[1]: docs.aws.amazon.com/kms/latest/developerguide/kms-cryptography.html#cryptographic-operations [2]: docs.aws.amazon.com/kms/latest/developerguide/conditions-kms.html#conditions-kms-encryption-context [3]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html [4]: docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcearn

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_context_equalsHash<String,String>

A list of key-value pairs that must match the encryption context in the [cryptographic operation] request. The grant allows the operation only when the encryption context in the request is the same as the encryption context specified in this constraint.

[1]: docs.aws.amazon.com/kms/latest/developerguide/kms-cryptography.html#cryptographic-operations

Returns:

  • (Hash<String,String>)


3988
3989
3990
3991
3992
3993
3994
# File 'lib/aws-sdk-kms/types.rb', line 3988

class GrantConstraints < Struct.new(
  :encryption_context_subset,
  :encryption_context_equals,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_context_subsetHash<String,String>

A list of key-value pairs that must be included in the encryption context of the [cryptographic operation] request. The grant allows the cryptographic operation only when the encryption context in the request includes the key-value pairs specified in this constraint, although it can include additional key-value pairs.

[1]: docs.aws.amazon.com/kms/latest/developerguide/kms-cryptography.html#cryptographic-operations

Returns:

  • (Hash<String,String>)


3988
3989
3990
3991
3992
3993
3994
# File 'lib/aws-sdk-kms/types.rb', line 3988

class GrantConstraints < Struct.new(
  :encryption_context_subset,
  :encryption_context_equals,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The [ Amazon Resource Name (ARN)] of an Amazon Web Services resource on behalf of which the request is made. This is effectively the same as having the [aws:SourceArn] global condition key in the grant. The SourceArn constraint ensures that the principal can use the KMS key only when the request is made on behalf of the specified resource.

[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html [2]: docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcearn

Returns:

  • (String)


3988
3989
3990
3991
3992
3993
3994
# File 'lib/aws-sdk-kms/types.rb', line 3988

class GrantConstraints < Struct.new(
  :encryption_context_subset,
  :encryption_context_equals,
  :source_arn)
  SENSITIVE = []
  include Aws::Structure
end