Method: Aws::KMS::Types::ImportKeyMaterialRequest#key_id

Defined in:
lib/aws-sdk-kms/types.rb

#key_idString

The identifier of the KMS key that will be associated with the imported key material. This must be the same KMS key specified in the KeyID parameter of the corresponding GetParametersForImport request. The Origin of the KMS key must be EXTERNAL and its KeyState must be PendingImport.

The KMS key can be a symmetric encryption KMS key, HMAC KMS key, asymmetric encryption KMS key, or asymmetric signing KMS key, including a [multi-Region key] of any supported type. You cannot perform this operation on a KMS key in a custom key store, or on a KMS key in a different Amazon Web Services account.

Specify the key ID or key ARN of the KMS key.

For example:

  • Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab

  • Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab

To get the key ID and key ARN for a KMS key, use ListKeys or DescribeKey.

[1]: docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html



4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/aws-sdk-kms/types.rb', line 4058

class ImportKeyMaterialRequest < Struct.new(
  :key_id,
  :import_token,
  :encrypted_key_material,
  :valid_to,
  :expiration_model,
  :import_type,
  :key_material_description,
  :key_material_id)
  SENSITIVE = []
  include Aws::Structure
end