Class: Aws::KMS::Types::InvalidCiphertextException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

From the Decrypt or ReEncrypt operation, the request was rejected because the specified ciphertext, or additional authenticated data incorporated into the ciphertext, such as the encryption context, is corrupted, missing, or otherwise invalid.

From the ImportKeyMaterial operation, the request was rejected because KMS could not decrypt the encrypted (wrapped) key material.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


4189
4190
4191
4192
4193
# File 'lib/aws-sdk-kms/types.rb', line 4189

class InvalidCiphertextException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end