Class: Aws::KMS::Types::KMSInvalidSignatureException
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::KMSInvalidSignatureException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
The request was rejected because the signature verification failed. Signature verification fails when it cannot confirm that signature was produced by signing the specified message with the specified KMS key and signing algorithm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
4478 4479 4480 4481 4482 |
# File 'lib/aws-sdk-kms/types.rb', line 4478 class KMSInvalidSignatureException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |