Class: Aws::KMS::Types::KeyLastUsageData
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::KeyLastUsageData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Contains usage information about the last time the KMS key was used for a successful cryptographic operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud_trail_event_id ⇒ String
The CloudTrail ‘eventId` associated with the last successful cryptographic operation.
-
#kms_request_id ⇒ String
The KMS request ID associated with the last successful cryptographic operation.
-
#operation ⇒ String
The last successful cryptographic operation the KMS key was used for.
-
#timestamp ⇒ Time
The date and time when the KMS key was most recently used for a successful cryptographic operation.
Instance Attribute Details
#cloud_trail_event_id ⇒ String
The CloudTrail ‘eventId` associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
4544 4545 4546 4547 4548 4549 4550 4551 |
# File 'lib/aws-sdk-kms/types.rb', line 4544 class KeyLastUsageData < Struct.new( :operation, :timestamp, :cloud_trail_event_id, :kms_request_id) SENSITIVE = [] include Aws::Structure end |
#kms_request_id ⇒ String
The KMS request ID associated with the last successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
4544 4545 4546 4547 4548 4549 4550 4551 |
# File 'lib/aws-sdk-kms/types.rb', line 4544 class KeyLastUsageData < Struct.new( :operation, :timestamp, :cloud_trail_event_id, :kms_request_id) SENSITIVE = [] include Aws::Structure end |
#operation ⇒ String
The last successful cryptographic operation the KMS key was used for. Absent if the key has not been used since KMS began tracking.
4544 4545 4546 4547 4548 4549 4550 4551 |
# File 'lib/aws-sdk-kms/types.rb', line 4544 class KeyLastUsageData < Struct.new( :operation, :timestamp, :cloud_trail_event_id, :kms_request_id) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Time
The date and time when the KMS key was most recently used for a successful cryptographic operation. Absent if the key has not been used since KMS began tracking.
4544 4545 4546 4547 4548 4549 4550 4551 |
# File 'lib/aws-sdk-kms/types.rb', line 4544 class KeyLastUsageData < Struct.new( :operation, :timestamp, :cloud_trail_event_id, :kms_request_id) SENSITIVE = [] include Aws::Structure end |