Class: Aws::KMS::Types::KeyMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::KeyMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Contains metadata about a KMS key.
This data type is used as a response element for the CreateKey, DescribeKey, and ReplicateKey operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key.
-
#aws_account_id ⇒ String
The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
-
#cloud_hsm_cluster_id ⇒ String
The cluster ID of the CloudHSM cluster that contains the key material for the KMS key.
-
#creation_date ⇒ Time
The date and time when the KMS key was created.
-
#current_key_material_id ⇒ String
Identifies the current key material.
-
#custom_key_store_id ⇒ String
A unique identifier for the [custom key store] that contains the KMS key.
-
#customer_master_key_spec ⇒ String
Instead, use the
KeySpecfield. -
#deletion_date ⇒ Time
The date and time after which KMS deletes this KMS key.
-
#description ⇒ String
The description of the KMS key.
-
#enabled ⇒ Boolean
Specifies whether the KMS key is enabled.
-
#encryption_algorithms ⇒ Array<String>
The encryption algorithms that the KMS key supports.
-
#expiration_model ⇒ String
Specifies whether the KMS key’s key material expires.
-
#key_agreement_algorithms ⇒ Array<String>
The key agreement algorithm used to derive a shared secret.
-
#key_id ⇒ String
The globally unique identifier for the KMS key.
-
#key_manager ⇒ String
The manager of the KMS key.
-
#key_spec ⇒ String
Describes the type of key material in the KMS key.
-
#key_state ⇒ String
The current status of the KMS key.
-
#key_usage ⇒ String
The [cryptographic operations] for which you can use the KMS key.
-
#mac_algorithms ⇒ Array<String>
The message authentication code (MAC) algorithm that the HMAC KMS key supports.
-
#multi_region ⇒ Boolean
Indicates whether the KMS key is a multi-Region (
True) or regional (False) key. -
#multi_region_configuration ⇒ Types::MultiRegionConfiguration
Lists the primary and replica keys in same multi-Region key.
-
#origin ⇒ String
The source of the key material for the KMS key.
-
#pending_deletion_window_in_days ⇒ Integer
The waiting period before the primary key in a multi-Region key is deleted.
-
#signing_algorithms ⇒ Array<String>
The signing algorithms that the KMS key supports.
-
#valid_to ⇒ Time
The earliest time at which any imported key material permanently associated with this KMS key expires.
-
#xks_key_configuration ⇒ Types::XksKeyConfigurationType
Information about the external key that is associated with a KMS key in an external key store.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key. For examples, see
- Key Management Service (KMS)][1
-
in the Example ARNs section of the
*Amazon Web Services General Reference*.
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#arn-syntax-kms
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#aws_account_id ⇒ String
The twelve-digit account ID of the Amazon Web Services account that owns the KMS key.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#cloud_hsm_cluster_id ⇒ String
The cluster ID of the CloudHSM cluster that contains the key material for the KMS key. When you create a KMS key in an CloudHSM [custom key store], KMS creates the key material for the KMS key in the associated CloudHSM cluster. This field is present only when the KMS key is created in an CloudHSM key store.
[1]: docs.aws.amazon.com/kms/latest/developerguide/key-store-overview.html
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time when the KMS key was created.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#current_key_material_id ⇒ String
Identifies the current key material. This value is present for symmetric encryption keys with AWS_KMS or EXTERNAL origin. These KMS keys support automatic or on-demand key rotation and can have multiple key materials associated with them. KMS uses the current key material for both encryption and decryption, and the non-current key material for decryption operations only.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#custom_key_store_id ⇒ String
A unique identifier for the [custom key store] that contains the KMS key. This field is present only when the KMS key is created in a custom key store.
[1]: docs.aws.amazon.com/kms/latest/developerguide/key-store-overview.html
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#customer_master_key_spec ⇒ String
Instead, use the KeySpec field.
The KeySpec and CustomerMasterKeySpec fields have the same value. We recommend that you use the KeySpec field in your code. However, to avoid breaking changes, KMS supports both fields.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#deletion_date ⇒ Time
The date and time after which KMS deletes this KMS key. This value is present only when the KMS key is scheduled for deletion, that is, when its KeyState is PendingDeletion.
When the primary key in a multi-Region key is scheduled for deletion but still has replica keys, its key state is PendingReplicaDeletion and the length of its waiting period is displayed in the PendingDeletionWindowInDays field.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the KMS key.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Specifies whether the KMS key is enabled. When KeyState is Enabled this value is true, otherwise it is false.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#encryption_algorithms ⇒ Array<String>
The encryption algorithms that the KMS key supports. You cannot use the KMS key with other encryption algorithms within KMS.
This value is present only when the KeyUsage of the KMS key is ENCRYPT_DECRYPT.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#expiration_model ⇒ String
Specifies whether the KMS key’s key material expires. This value is present only when Origin is EXTERNAL, otherwise this value is omitted.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#key_agreement_algorithms ⇒ Array<String>
The key agreement algorithm used to derive a shared secret.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The globally unique identifier for the KMS key.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#key_manager ⇒ String
The manager of the KMS key. KMS keys in your Amazon Web Services account are either customer managed or Amazon Web Services managed. For more information about the difference, see [KMS keys] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#kms_keys
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#key_spec ⇒ String
Describes the type of key material in the KMS key.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#key_state ⇒ String
The current status of the KMS key.
For more information about how key state affects the use of a KMS key, see [Key states of KMS keys] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/key-state.html
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#key_usage ⇒ String
The [cryptographic operations] for which you can use the KMS key.
[1]: docs.aws.amazon.com/kms/latest/developerguide/kms-cryptography.html#cryptographic-operations
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#mac_algorithms ⇒ Array<String>
The message authentication code (MAC) algorithm that the HMAC KMS key supports.
This value is present only when the KeyUsage of the KMS key is GENERATE_VERIFY_MAC.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#multi_region ⇒ Boolean
Indicates whether the KMS key is a multi-Region (True) or regional (False) key. This value is True for multi-Region primary and replica keys and False for regional KMS keys.
For more information about multi-Region keys, see [Multi-Region keys in KMS] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/multi-region-keys-overview.html
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#multi_region_configuration ⇒ Types::MultiRegionConfiguration
Lists the primary and replica keys in same multi-Region key. This field is present only when the value of the MultiRegion field is True.
For more information about any listed KMS key, use the DescribeKey operation.
-
MultiRegionKeyTypeindicates whether the KMS key is aPRIMARYorREPLICAkey. -
PrimaryKeydisplays the key ARN and Region of the primary key. This field displays the current KMS key if it is the primary key. -
ReplicaKeysdisplays the key ARNs and Regions of all replica keys. This field includes the current KMS key if it is a replica key.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#origin ⇒ String
The source of the key material for the KMS key. When this value is AWS_KMS, KMS created the key material. When this value is EXTERNAL, the key material was imported or the KMS key doesn’t have any key material. When this value is AWS_CLOUDHSM, the key material was created in the CloudHSM cluster associated with a custom key store.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#pending_deletion_window_in_days ⇒ Integer
The waiting period before the primary key in a multi-Region key is deleted. This waiting period begins when the last of its replica keys is deleted. This value is present only when the KeyState of the KMS key is PendingReplicaDeletion. That indicates that the KMS key is the primary key in a multi-Region key, it is scheduled for deletion, and it still has existing replica keys.
When a single-Region KMS key or a multi-Region replica key is scheduled for deletion, its deletion date is displayed in the DeletionDate field. However, when the primary key in a multi-Region key is scheduled for deletion, its waiting period doesn’t begin until all of its replica keys are deleted. This value displays that waiting period. When the last replica key in the multi-Region key is deleted, the KeyState of the scheduled primary key changes from PendingReplicaDeletion to PendingDeletion and the deletion date appears in the DeletionDate field.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#signing_algorithms ⇒ Array<String>
The signing algorithms that the KMS key supports. You cannot use the KMS key with other signing algorithms within KMS.
This field appears only when the KeyUsage of the KMS key is SIGN_VERIFY.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#valid_to ⇒ Time
The earliest time at which any imported key material permanently associated with this KMS key expires. When a key material expires, KMS deletes the key material and the KMS key becomes unusable. This value is present only for KMS keys whose Origin is EXTERNAL and the ExpirationModel is KEY_MATERIAL_EXPIRES, otherwise this value is omitted.
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |
#xks_key_configuration ⇒ Types::XksKeyConfigurationType
Information about the external key that is associated with a KMS key in an external key store.
For more information, see [External key] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/keystore-external.html#concept-external-key
4617 4618 4619 4620 4621 4622 4623 4624 4625 4626 4627 4628 4629 4630 4631 4632 4633 4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-kms/types.rb', line 4617 class KeyMetadata < Struct.new( :aws_account_id, :key_id, :arn, :creation_date, :enabled, :description, :key_usage, :key_state, :deletion_date, :valid_to, :origin, :custom_key_store_id, :cloud_hsm_cluster_id, :expiration_model, :key_manager, :customer_master_key_spec, :key_spec, :encryption_algorithms, :signing_algorithms, :key_agreement_algorithms, :multi_region, :multi_region_configuration, :pending_deletion_window_in_days, :mac_algorithms, :xks_key_configuration, :current_key_material_id) SENSITIVE = [] include Aws::Structure end |