Class: Aws::KMS::Types::ListGrantsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::ListGrantsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#grant_id ⇒ String
Returns only the grant with the specified grant ID.
-
#grantee_principal ⇒ String
Returns only grants where the specified principal is the grantee principal for the grant.
-
#grantee_service_principal ⇒ String
Returns only grants where the specified Amazon Web Services service principal is the grantee service principal for the grant.
-
#key_id ⇒ String
Returns only grants for the specified KMS key.
-
#limit ⇒ Integer
Use this parameter to specify the maximum number of items to return.
-
#marker ⇒ String
Use this parameter in a subsequent request after you receive a response with truncated results.
Instance Attribute Details
#grant_id ⇒ String
Returns only the grant with the specified grant ID. The grant ID uniquely identifies the grant.
5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 |
# File 'lib/aws-sdk-kms/types.rb', line 5006 class ListGrantsRequest < Struct.new( :limit, :marker, :key_id, :grant_id, :grantee_principal, :grantee_service_principal) SENSITIVE = [] include Aws::Structure end |
#grantee_principal ⇒ String
Returns only grants where the specified principal is the grantee principal for the grant.
You can specify either GranteePrincipal or
GranteeServicePrincipal, but not both.
5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 |
# File 'lib/aws-sdk-kms/types.rb', line 5006 class ListGrantsRequest < Struct.new( :limit, :marker, :key_id, :grant_id, :grantee_principal, :grantee_service_principal) SENSITIVE = [] include Aws::Structure end |
#grantee_service_principal ⇒ String
Returns only grants where the specified Amazon Web Services service principal is the grantee service principal for the grant. This filter is only usable by callers in a service principal.
You can specify either GranteePrincipal or
GranteeServicePrincipal, but not both.
5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 |
# File 'lib/aws-sdk-kms/types.rb', line 5006 class ListGrantsRequest < Struct.new( :limit, :marker, :key_id, :grant_id, :grantee_principal, :grantee_service_principal) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
Returns only grants for the specified KMS key. This parameter is required.
Specify the key ID or key ARN of the KMS key. To specify a KMS key in a different Amazon Web Services account, you must use the key ARN.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
To get the key ID and key ARN for a KMS key, use ListKeys or DescribeKey.
5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 |
# File 'lib/aws-sdk-kms/types.rb', line 5006 class ListGrantsRequest < Struct.new( :limit, :marker, :key_id, :grant_id, :grantee_principal, :grantee_service_principal) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
Use this parameter to specify the maximum number of items to return. When this value is present, KMS does not return more than the specified number of items, but it might return fewer.
This value is optional. If you include a value, it must be between 1 and 100, inclusive. If you do not include a value, it defaults to 50.
5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 |
# File 'lib/aws-sdk-kms/types.rb', line 5006 class ListGrantsRequest < Struct.new( :limit, :marker, :key_id, :grant_id, :grantee_principal, :grantee_service_principal) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter in a subsequent request after you receive a
response with truncated results. Set it to the value of NextMarker
from the truncated response you just received.
5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 |
# File 'lib/aws-sdk-kms/types.rb', line 5006 class ListGrantsRequest < Struct.new( :limit, :marker, :key_id, :grant_id, :grantee_principal, :grantee_service_principal) SENSITIVE = [] include Aws::Structure end |