Class: Aws::KMS::Types::ListGrantsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#grantsArray<Types::GrantListEntry>

A list of grants.

Returns:



5035
5036
5037
5038
5039
5040
5041
# File 'lib/aws-sdk-kms/types.rb', line 5035

class ListGrantsResponse < Struct.new(
  :grants,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

When Truncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent request.

Returns:

  • (String)


5035
5036
5037
5038
5039
5040
5041
# File 'lib/aws-sdk-kms/types.rb', line 5035

class ListGrantsResponse < Struct.new(
  :grants,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end

#truncatedBoolean

A flag that indicates whether there are more items in the list. When this value is true, the list in this response is truncated. To get more items, pass the value of the NextMarker element in this response to the Marker parameter in a subsequent request.

Returns:

  • (Boolean)


5035
5036
5037
5038
5039
5040
5041
# File 'lib/aws-sdk-kms/types.rb', line 5035

class ListGrantsResponse < Struct.new(
  :grants,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end