Class: Aws::KMS::Types::ListKeyPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::ListKeyPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key_id ⇒ String
Gets the names of key policies for the specified KMS key.
-
#limit ⇒ Integer
Use this parameter to specify the maximum number of items to return.
-
#marker ⇒ String
Use this parameter in a subsequent request after you receive a response with truncated results.
Instance Attribute Details
#key_id ⇒ String
Gets the names of key policies for the specified KMS key.
Specify the key ID or key ARN of the KMS key.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
To get the key ID and key ARN for a KMS key, use ListKeys or DescribeKey.
4872 4873 4874 4875 4876 4877 4878 |
# File 'lib/aws-sdk-kms/types.rb', line 4872 class ListKeyPoliciesRequest < Struct.new( :key_id, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
Use this parameter to specify the maximum number of items to return. When this value is present, KMS does not return more than the specified number of items, but it might return fewer.
This value is optional. If you include a value, it must be between 1 and 1000, inclusive. If you do not include a value, it defaults to 100.
Only one policy can be attached to a key.
4872 4873 4874 4875 4876 4877 4878 |
# File 'lib/aws-sdk-kms/types.rb', line 4872 class ListKeyPoliciesRequest < Struct.new( :key_id, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received.
4872 4873 4874 4875 4876 4877 4878 |
# File 'lib/aws-sdk-kms/types.rb', line 4872 class ListKeyPoliciesRequest < Struct.new( :key_id, :limit, :marker) SENSITIVE = [] include Aws::Structure end |