Class: Aws::KMS::Types::ListKeyPoliciesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::ListKeyPoliciesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
When
Truncatedis true, this element is present and contains the value to use for theMarkerparameter in a subsequent request. -
#policy_names ⇒ Array<String>
A list of key policy names.
-
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list.
Instance Attribute Details
#next_marker ⇒ String
When Truncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent request.
4898 4899 4900 4901 4902 4903 4904 |
# File 'lib/aws-sdk-kms/types.rb', line 4898 class ListKeyPoliciesResponse < Struct.new( :policy_names, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#policy_names ⇒ Array<String>
A list of key policy names. The only valid value is default.
4898 4899 4900 4901 4902 4903 4904 |
# File 'lib/aws-sdk-kms/types.rb', line 4898 class ListKeyPoliciesResponse < Struct.new( :policy_names, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list. When this value is true, the list in this response is truncated. To get more items, pass the value of the NextMarker element in this response to the Marker parameter in a subsequent request.
4898 4899 4900 4901 4902 4903 4904 |
# File 'lib/aws-sdk-kms/types.rb', line 4898 class ListKeyPoliciesResponse < Struct.new( :policy_names, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |