Class: Aws::KMS::Types::ListKeyRotationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_markerString

When Truncated is true, this element is present and contains the value to use for the Marker parameter in a subsequent request.

Returns:

  • (String)


5189
5190
5191
5192
5193
5194
5195
# File 'lib/aws-sdk-kms/types.rb', line 5189

class ListKeyRotationsResponse < Struct.new(
  :rotations,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end

#rotationsArray<Types::RotationsListEntry>

A list of completed key material rotations. When the optional input parameter IncludeKeyMaterial is specified with a value of ALL_KEY_MATERIAL, this list includes the first key material and any imported key material pending rotation.

Returns:



5189
5190
5191
5192
5193
5194
5195
# File 'lib/aws-sdk-kms/types.rb', line 5189

class ListKeyRotationsResponse < Struct.new(
  :rotations,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end

#truncatedBoolean

A flag that indicates whether there are more items in the list. When this value is true, the list in this response is truncated. To get more items, pass the value of the NextMarker element in this response to the Marker parameter in a subsequent request.

Returns:

  • (Boolean)


5189
5190
5191
5192
5193
5194
5195
# File 'lib/aws-sdk-kms/types.rb', line 5189

class ListKeyRotationsResponse < Struct.new(
  :rotations,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end