Class: Aws::KMS::Types::ListKeysRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#limitInteger

Use this parameter to specify the maximum number of items to return. When this value is present, KMS does not return more than the specified number of items, but it might return fewer.

This value is optional. If you include a value, it must be between 1 and 1000, inclusive. If you do not include a value, it defaults to 100.

Returns:

  • (Integer)


5008
5009
5010
5011
5012
5013
# File 'lib/aws-sdk-kms/types.rb', line 5008

class ListKeysRequest < Struct.new(
  :limit,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Use this parameter in a subsequent request after you receive a response with truncated results. Set it to the value of NextMarker from the truncated response you just received.

Returns:

  • (String)


5008
5009
5010
5011
5012
5013
# File 'lib/aws-sdk-kms/types.rb', line 5008

class ListKeysRequest < Struct.new(
  :limit,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end