Class: Aws::KMS::Types::ListKeysResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::ListKeysResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#keys ⇒ Array<Types::KeyListEntry>
A list of KMS keys.
-
#next_marker ⇒ String
When
Truncatedis true, this element is present and contains the value to use for theMarkerparameter in a subsequent request. -
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list.
Instance Attribute Details
#keys ⇒ Array<Types::KeyListEntry>
A list of KMS keys.
5240 5241 5242 5243 5244 5245 5246 |
# File 'lib/aws-sdk-kms/types.rb', line 5240 class ListKeysResponse < Struct.new( :keys, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
When Truncated is true, this element is present and contains the
value to use for the Marker parameter in a subsequent request.
5240 5241 5242 5243 5244 5245 5246 |
# File 'lib/aws-sdk-kms/types.rb', line 5240 class ListKeysResponse < Struct.new( :keys, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list. When
this value is true, the list in this response is truncated. To get
more items, pass the value of the NextMarker element in this
response to the Marker parameter in a subsequent request.
5240 5241 5242 5243 5244 5245 5246 |
# File 'lib/aws-sdk-kms/types.rb', line 5240 class ListKeysResponse < Struct.new( :keys, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |