Class: Aws::KMS::Types::RecipientInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Contains information about the party that receives the response from the API operation.

This data type is designed to support Amazon Web Services Nitro Enclaves and Amazon Web Services NitroTPM, which lets you create an attested environment in Amazon EC2. For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see [Cryptographic attestation support in KMS] in the *Key Management Service Developer Guide*.

[1]: docs.aws.amazon.com/kms/latest/developerguide/cryptographic-attestation.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attestation_documentString

The attestation document for an Amazon Web Services Nitro Enclave or a NitroTPM. This document includes the enclave’s public key.

Returns:

  • (String)


5743
5744
5745
5746
5747
5748
# File 'lib/aws-sdk-kms/types.rb', line 5743

class RecipientInfo < Struct.new(
  :key_encryption_algorithm,
  :attestation_document)
  SENSITIVE = []
  include Aws::Structure
end

#key_encryption_algorithmString

The encryption algorithm that KMS should use with the public key for an Amazon Web Services Nitro Enclave or NitroTPM to encrypt plaintext values for the response. The only valid value is ‘RSAES_OAEP_SHA_256`.

Returns:

  • (String)


5743
5744
5745
5746
5747
5748
# File 'lib/aws-sdk-kms/types.rb', line 5743

class RecipientInfo < Struct.new(
  :key_encryption_algorithm,
  :attestation_document)
  SENSITIVE = []
  include Aws::Structure
end