Class: Aws::KMS::Types::ScheduleKeyDeletionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletion_dateTime

The date and time after which KMS deletes the KMS key.

If the KMS key is a multi-Region primary key with replica keys, this field does not appear. The deletion date for the primary key isn't known until its last replica key is deleted.



6429
6430
6431
6432
6433
6434
6435
6436
# File 'lib/aws-sdk-kms/types.rb', line 6429

class ScheduleKeyDeletionResponse < Struct.new(
  :key_id,
  :deletion_date,
  :key_state,
  :pending_window_in_days)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The Amazon Resource Name (key ARN) of the KMS key whose deletion is scheduled.



6429
6430
6431
6432
6433
6434
6435
6436
# File 'lib/aws-sdk-kms/types.rb', line 6429

class ScheduleKeyDeletionResponse < Struct.new(
  :key_id,
  :deletion_date,
  :key_state,
  :pending_window_in_days)
  SENSITIVE = []
  include Aws::Structure
end

#key_stateString

The current status of the KMS key.

For more information about how key state affects the use of a KMS key, see Key states of KMS keys in the Key Management Service Developer Guide.



6429
6430
6431
6432
6433
6434
6435
6436
# File 'lib/aws-sdk-kms/types.rb', line 6429

class ScheduleKeyDeletionResponse < Struct.new(
  :key_id,
  :deletion_date,
  :key_state,
  :pending_window_in_days)
  SENSITIVE = []
  include Aws::Structure
end

#pending_window_in_daysInteger

The waiting period before the KMS key is deleted.

If the KMS key is a multi-Region primary key with replicas, the waiting period begins when the last of its replica keys is deleted. Otherwise, the waiting period begins immediately.



6429
6430
6431
6432
6433
6434
6435
6436
# File 'lib/aws-sdk-kms/types.rb', line 6429

class ScheduleKeyDeletionResponse < Struct.new(
  :key_id,
  :deletion_date,
  :key_state,
  :pending_window_in_days)
  SENSITIVE = []
  include Aws::Structure
end