Class: Aws::KMS::Types::UpdateKeyDescriptionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::UpdateKeyDescriptionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
New description for the KMS key.
-
#key_id ⇒ String
Updates the description of the specified KMS key.
Instance Attribute Details
#description ⇒ String
New description for the KMS key.
Do not include confidential or sensitive information in this field. This field may be displayed in plaintext in CloudTrail logs and other output.
6781 6782 6783 6784 6785 6786 |
# File 'lib/aws-sdk-kms/types.rb', line 6781 class UpdateKeyDescriptionRequest < Struct.new( :key_id, :description) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
Updates the description of the specified KMS key.
Specify the key ID or key ARN of the KMS key.
For example:
-
Key ID:
1234abcd-12ab-34cd-56ef-1234567890ab -
Key ARN:
arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab
To get the key ID and key ARN for a KMS key, use ListKeys or DescribeKey.
6781 6782 6783 6784 6785 6786 |
# File 'lib/aws-sdk-kms/types.rb', line 6781 class UpdateKeyDescriptionRequest < Struct.new( :key_id, :description) SENSITIVE = [] include Aws::Structure end |