Class: Aws::KMS::Types::XksKeyInvalidConfigurationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

The request was rejected because the external key specified by the XksKeyId parameter did not meet the configuration requirements for an external key store.

The external key must be an AES-256 symmetric key that is enabled and performs encryption and decryption.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


7156
7157
7158
7159
7160
# File 'lib/aws-sdk-kms/types.rb', line 7156

class XksKeyInvalidConfigurationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end