Class: Aws::KMS::Types::XksKeyNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::XksKeyNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
The request was rejected because the external key store proxy could not find the external key. This exception is thrown when the value of the XksKeyId parameter doesn’t identify a key in the external key manager associated with the external key proxy.
Verify that the XksKeyId represents an existing key in the external key manager. Use the key identifier that the external key store proxy uses to identify the key. For details, see the documentation provided with your external key store proxy or key manager.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7177 7178 7179 7180 7181 |
# File 'lib/aws-sdk-kms/types.rb', line 7177 class XksKeyNotFoundException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |