Class: Aws::KMS::Types::XksProxyAuthenticationCredentialType
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::XksProxyAuthenticationCredentialType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
KMS uses the authentication credential to sign requests that it sends to the external key store proxy (XKS proxy) on your behalf. You establish these credentials on your external key store proxy and report them to KMS.
The XksProxyAuthenticationCredential includes two required elements.
Constant Summary collapse
- SENSITIVE =
[:access_key_id, :raw_secret_access_key]
Instance Attribute Summary collapse
-
#access_key_id ⇒ String
A unique identifier for the raw secret access key.
-
#raw_secret_access_key ⇒ String
A secret string of 43-64 characters.
Instance Attribute Details
#access_key_id ⇒ String
A unique identifier for the raw secret access key.
7201 7202 7203 7204 7205 7206 |
# File 'lib/aws-sdk-kms/types.rb', line 7201 class XksProxyAuthenticationCredentialType < Struct.new( :access_key_id, :raw_secret_access_key) SENSITIVE = [:access_key_id, :raw_secret_access_key] include Aws::Structure end |
#raw_secret_access_key ⇒ String
A secret string of 43-64 characters. Valid characters are a-z, A-Z, 0-9, /, +, and =.
7201 7202 7203 7204 7205 7206 |
# File 'lib/aws-sdk-kms/types.rb', line 7201 class XksProxyAuthenticationCredentialType < Struct.new( :access_key_id, :raw_secret_access_key) SENSITIVE = [:access_key_id, :raw_secret_access_key] include Aws::Structure end |