Class: Aws::KMS::Types::XksProxyConfigurationType
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::XksProxyConfigurationType
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Detailed information about the external key store proxy (XKS proxy). Your external key store proxy translates KMS requests into a format that your external key manager can understand. These fields appear in a DescribeCustomKeyStores response only when the CustomKeyStoreType is EXTERNAL_KEY_STORE.
Constant Summary collapse
- SENSITIVE =
[:access_key_id]
Instance Attribute Summary collapse
-
#access_key_id ⇒ String
The part of the external key store [proxy authentication credential] that uniquely identifies the secret access key.
-
#connectivity ⇒ String
Indicates whether the external key store proxy uses a public endpoint or an Amazon VPC endpoint service to communicate with KMS.
-
#uri_endpoint ⇒ String
The URI endpoint for the external key store proxy.
-
#uri_path ⇒ String
The path to the external key store proxy APIs.
-
#vpc_endpoint_service_name ⇒ String
The Amazon VPC endpoint service used to communicate with the external key store proxy.
-
#vpc_endpoint_service_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon VPC endpoint service used to communicate with the external key store proxy (XKS).
Instance Attribute Details
#access_key_id ⇒ String
The part of the external key store [proxy authentication credential] that uniquely identifies the secret access key.
7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 |
# File 'lib/aws-sdk-kms/types.rb', line 7259 class XksProxyConfigurationType < Struct.new( :connectivity, :access_key_id, :uri_endpoint, :uri_path, :vpc_endpoint_service_name, :vpc_endpoint_service_owner) SENSITIVE = [:access_key_id] include Aws::Structure end |
#connectivity ⇒ String
Indicates whether the external key store proxy uses a public endpoint or an Amazon VPC endpoint service to communicate with KMS.
7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 |
# File 'lib/aws-sdk-kms/types.rb', line 7259 class XksProxyConfigurationType < Struct.new( :connectivity, :access_key_id, :uri_endpoint, :uri_path, :vpc_endpoint_service_name, :vpc_endpoint_service_owner) SENSITIVE = [:access_key_id] include Aws::Structure end |
#uri_endpoint ⇒ String
The URI endpoint for the external key store proxy.
If the external key store proxy has a public endpoint, it is displayed here.
If the external key store proxy uses an Amazon VPC endpoint service name, this field displays the private DNS name associated with the VPC endpoint service.
7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 |
# File 'lib/aws-sdk-kms/types.rb', line 7259 class XksProxyConfigurationType < Struct.new( :connectivity, :access_key_id, :uri_endpoint, :uri_path, :vpc_endpoint_service_name, :vpc_endpoint_service_owner) SENSITIVE = [:access_key_id] include Aws::Structure end |
#uri_path ⇒ String
The path to the external key store proxy APIs.
7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 |
# File 'lib/aws-sdk-kms/types.rb', line 7259 class XksProxyConfigurationType < Struct.new( :connectivity, :access_key_id, :uri_endpoint, :uri_path, :vpc_endpoint_service_name, :vpc_endpoint_service_owner) SENSITIVE = [:access_key_id] include Aws::Structure end |
#vpc_endpoint_service_name ⇒ String
The Amazon VPC endpoint service used to communicate with the external key store proxy. This field appears only when the external key store proxy uses an Amazon VPC endpoint service to communicate with KMS.
7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 |
# File 'lib/aws-sdk-kms/types.rb', line 7259 class XksProxyConfigurationType < Struct.new( :connectivity, :access_key_id, :uri_endpoint, :uri_path, :vpc_endpoint_service_name, :vpc_endpoint_service_owner) SENSITIVE = [:access_key_id] include Aws::Structure end |
#vpc_endpoint_service_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon VPC endpoint service used to communicate with the external key store proxy (XKS). This field appears only when the XKS uses an VPC endpoint service to communicate with KMS.
7259 7260 7261 7262 7263 7264 7265 7266 7267 7268 |
# File 'lib/aws-sdk-kms/types.rb', line 7259 class XksProxyConfigurationType < Struct.new( :connectivity, :access_key_id, :uri_endpoint, :uri_path, :vpc_endpoint_service_name, :vpc_endpoint_service_owner) SENSITIVE = [:access_key_id] include Aws::Structure end |