Class: Aws::KMS::Types::XksProxyInvalidConfigurationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

The request was rejected because the external key store proxy is not configured correctly. To identify the cause, see the error message that accompanies the exception.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


7527
7528
7529
7530
7531
# File 'lib/aws-sdk-kms/types.rb', line 7527

class XksProxyInvalidConfigurationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end