Class: Aws::KMS::Types::XksProxyUriEndpointInUseException
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::XksProxyUriEndpointInUseException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
The request was rejected because the XksProxyUriEndpoint is already associated with another external key store in this Amazon Web Services Region. To identify the cause, see the error message that accompanies the exception.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7328 7329 7330 7331 7332 |
# File 'lib/aws-sdk-kms/types.rb', line 7328 class XksProxyUriEndpointInUseException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |