Class: Aws::KMS::Types::XksProxyUriInUseException
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::XksProxyUriInUseException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
The request was rejected because the concatenation of the XksProxyUriEndpoint and XksProxyUriPath is already associated with another external key store in this Amazon Web Services Region. Each external key store in a Region must use a unique external key store proxy API address.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7345 7346 7347 7348 7349 |
# File 'lib/aws-sdk-kms/types.rb', line 7345 class XksProxyUriInUseException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |