Class: Aws::KMS::Types::DecryptResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:plaintext]

Instance Attribute Summary collapse

Instance Attribute Details

#ciphertext_for_recipientString

The plaintext data encrypted with the public key from the attestation document. This ciphertext can be decrypted only by using a private key from the attested environment.

This field is included in the response only when the ‘Recipient` parameter in the request includes a valid attestation document from an Amazon Web Services Nitro enclave or NitroTPM. For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see [Cryptographic attestation support in KMS] in the *Key Management Service Developer Guide*.

[1]: docs.aws.amazon.com/kms/latest/developerguide/cryptographic-attestation.html

Returns:

  • (String)


1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-kms/types.rb', line 1777

class DecryptResponse < Struct.new(
  :key_id,
  :plaintext,
  :encryption_algorithm,
  :ciphertext_for_recipient,
  :key_material_id)
  SENSITIVE = [:plaintext]
  include Aws::Structure
end

#encryption_algorithmString

The encryption algorithm that was used to decrypt the ciphertext.

Returns:

  • (String)


1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-kms/types.rb', line 1777

class DecryptResponse < Struct.new(
  :key_id,
  :plaintext,
  :encryption_algorithm,
  :ciphertext_for_recipient,
  :key_material_id)
  SENSITIVE = [:plaintext]
  include Aws::Structure
end

#key_idString

The Amazon Resource Name ([key ARN]) of the KMS key that was used to decrypt the ciphertext.

[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-ARN

Returns:

  • (String)


1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-kms/types.rb', line 1777

class DecryptResponse < Struct.new(
  :key_id,
  :plaintext,
  :encryption_algorithm,
  :ciphertext_for_recipient,
  :key_material_id)
  SENSITIVE = [:plaintext]
  include Aws::Structure
end

#key_material_idString

The identifier of the key material used to decrypt the ciphertext. This field is present only when the operation uses a symmetric encryption KMS key. This field is omitted if the request includes the ‘Recipient` parameter.

Returns:

  • (String)


1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-kms/types.rb', line 1777

class DecryptResponse < Struct.new(
  :key_id,
  :plaintext,
  :encryption_algorithm,
  :ciphertext_for_recipient,
  :key_material_id)
  SENSITIVE = [:plaintext]
  include Aws::Structure
end

#plaintextString

Decrypted plaintext data. When you use the HTTP API or the Amazon Web Services CLI, the value is Base64-encoded. Otherwise, it is not Base64-encoded.

If the response includes the ‘CiphertextForRecipient` field, the `Plaintext` field is null or empty.

Returns:

  • (String)


1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/aws-sdk-kms/types.rb', line 1777

class DecryptResponse < Struct.new(
  :key_id,
  :plaintext,
  :encryption_algorithm,
  :ciphertext_for_recipient,
  :key_material_id)
  SENSITIVE = [:plaintext]
  include Aws::Structure
end