Class: Aws::KMS::Types::DescribeCustomKeyStoresResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::DescribeCustomKeyStoresResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_key_stores ⇒ Array<Types::CustomKeyStoresListEntry>
Contains metadata about each custom key store.
-
#next_marker ⇒ String
When
Truncatedis true, this element is present and contains the value to use for theMarkerparameter in a subsequent request. -
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list.
Instance Attribute Details
#custom_key_stores ⇒ Array<Types::CustomKeyStoresListEntry>
Contains metadata about each custom key store.
2196 2197 2198 2199 2200 2201 2202 |
# File 'lib/aws-sdk-kms/types.rb', line 2196 class DescribeCustomKeyStoresResponse < Struct.new( :custom_key_stores, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
When Truncated is true, this element is present and contains the
value to use for the Marker parameter in a subsequent request.
2196 2197 2198 2199 2200 2201 2202 |
# File 'lib/aws-sdk-kms/types.rb', line 2196 class DescribeCustomKeyStoresResponse < Struct.new( :custom_key_stores, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list. When
this value is true, the list in this response is truncated. To get
more items, pass the value of the NextMarker element in this
response to the Marker parameter in a subsequent request.
2196 2197 2198 2199 2200 2201 2202 |
# File 'lib/aws-sdk-kms/types.rb', line 2196 class DescribeCustomKeyStoresResponse < Struct.new( :custom_key_stores, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |