Class: Aws::KMS::Types::DescribeCustomKeyStoresResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_key_storesArray<Types::CustomKeyStoresListEntry>

Contains metadata about each custom key store.



2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-kms/types.rb', line 2145

class DescribeCustomKeyStoresResponse < Struct.new(
  :custom_key_stores,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end

#next_markerString

When ‘Truncated` is true, this element is present and contains the value to use for the `Marker` parameter in a subsequent request.

Returns:

  • (String)


2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-kms/types.rb', line 2145

class DescribeCustomKeyStoresResponse < Struct.new(
  :custom_key_stores,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end

#truncatedBoolean

A flag that indicates whether there are more items in the list. When this value is true, the list in this response is truncated. To get more items, pass the value of the ‘NextMarker` element in this response to the `Marker` parameter in a subsequent request.

Returns:

  • (Boolean)


2145
2146
2147
2148
2149
2150
2151
# File 'lib/aws-sdk-kms/types.rb', line 2145

class DescribeCustomKeyStoresResponse < Struct.new(
  :custom_key_stores,
  :next_marker,
  :truncated)
  SENSITIVE = []
  include Aws::Structure
end