Class: Aws::KMS::Types::GenerateDataKeyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::GenerateDataKeyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:plaintext]
Instance Attribute Summary collapse
-
#ciphertext_blob ⇒ String
The encrypted copy of the data key.
-
#ciphertext_for_recipient ⇒ String
The plaintext data key encrypted with the public key from the attestation document.
-
#key_id ⇒ String
The Amazon Resource Name ([key ARN]) of the KMS key that encrypted the data key.
-
#key_material_id ⇒ String
The identifier of the key material used to encrypt the data key.
-
#plaintext ⇒ String
The plaintext data key.
Instance Attribute Details
#ciphertext_blob ⇒ String
The encrypted copy of the data key. When you use the HTTP API or the Amazon Web Services CLI, the value is Base64-encoded. Otherwise, it is not Base64-encoded.
3154 3155 3156 3157 3158 3159 3160 3161 3162 |
# File 'lib/aws-sdk-kms/types.rb', line 3154 class GenerateDataKeyResponse < Struct.new( :ciphertext_blob, :plaintext, :key_id, :ciphertext_for_recipient, :key_material_id) SENSITIVE = [:plaintext] include Aws::Structure end |
#ciphertext_for_recipient ⇒ String
The plaintext data key encrypted with the public key from the attestation document. This ciphertext can be decrypted only by using a private key from the attested environment.
This field is included in the response only when the ‘Recipient` parameter in the request includes a valid attestation document from an Amazon Web Services Nitro enclave or NitroTPM. For information about the interaction between KMS and Amazon Web Services Nitro Enclaves or Amazon Web Services NitroTPM, see [Cryptographic attestation support in KMS] in the *Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/cryptographic-attestation.html
3154 3155 3156 3157 3158 3159 3160 3161 3162 |
# File 'lib/aws-sdk-kms/types.rb', line 3154 class GenerateDataKeyResponse < Struct.new( :ciphertext_blob, :plaintext, :key_id, :ciphertext_for_recipient, :key_material_id) SENSITIVE = [:plaintext] include Aws::Structure end |
#key_id ⇒ String
The Amazon Resource Name ([key ARN]) of the KMS key that encrypted the data key.
[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-ARN
3154 3155 3156 3157 3158 3159 3160 3161 3162 |
# File 'lib/aws-sdk-kms/types.rb', line 3154 class GenerateDataKeyResponse < Struct.new( :ciphertext_blob, :plaintext, :key_id, :ciphertext_for_recipient, :key_material_id) SENSITIVE = [:plaintext] include Aws::Structure end |
#key_material_id ⇒ String
The identifier of the key material used to encrypt the data key. This field is omitted if the request includes the ‘Recipient` parameter.
3154 3155 3156 3157 3158 3159 3160 3161 3162 |
# File 'lib/aws-sdk-kms/types.rb', line 3154 class GenerateDataKeyResponse < Struct.new( :ciphertext_blob, :plaintext, :key_id, :ciphertext_for_recipient, :key_material_id) SENSITIVE = [:plaintext] include Aws::Structure end |
#plaintext ⇒ String
The plaintext data key. When you use the HTTP API or the Amazon Web Services CLI, the value is Base64-encoded. Otherwise, it is not Base64-encoded. Use this data key to encrypt your data outside of KMS. Then, remove it from memory as soon as possible.
If the response includes the ‘CiphertextForRecipient` field, the `Plaintext` field is null or empty.
3154 3155 3156 3157 3158 3159 3160 3161 3162 |
# File 'lib/aws-sdk-kms/types.rb', line 3154 class GenerateDataKeyResponse < Struct.new( :ciphertext_blob, :plaintext, :key_id, :ciphertext_for_recipient, :key_material_id) SENSITIVE = [:plaintext] include Aws::Structure end |