Class: Aws::KMS::Types::GetKeyLastUsageResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kms/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#key_creation_dateTime

The date and time when the KMS key was created.

Returns:

  • (Time)


3476
3477
3478
3479
3480
3481
3482
3483
# File 'lib/aws-sdk-kms/types.rb', line 3476

class GetKeyLastUsageResponse < Struct.new(
  :key_id,
  :key_last_usage,
  :tracking_start_date,
  :key_creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The globally unique identifier for the KMS key.

Returns:

  • (String)


3476
3477
3478
3479
3480
3481
3482
3483
# File 'lib/aws-sdk-kms/types.rb', line 3476

class GetKeyLastUsageResponse < Struct.new(
  :key_id,
  :key_last_usage,
  :tracking_start_date,
  :key_creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#key_last_usageTypes::KeyLastUsageData

Contains usage information about the last time the KMS key was used for a successful cryptographic operation. If the key has not been used since tracking began, this response element is empty.



3476
3477
3478
3479
3480
3481
3482
3483
# File 'lib/aws-sdk-kms/types.rb', line 3476

class GetKeyLastUsageResponse < Struct.new(
  :key_id,
  :key_last_usage,
  :tracking_start_date,
  :key_creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_start_dateTime

The date from which KMS began recording cryptographic activity for this key, or the date the KMS key was created, whichever is later.

Returns:

  • (Time)


3476
3477
3478
3479
3480
3481
3482
3483
# File 'lib/aws-sdk-kms/types.rb', line 3476

class GetKeyLastUsageResponse < Struct.new(
  :key_id,
  :key_last_usage,
  :tracking_start_date,
  :key_creation_date)
  SENSITIVE = []
  include Aws::Structure
end