Class: Aws::KMS::Types::ListGrantsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::ListGrantsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#grants ⇒ Array<Types::GrantListEntry>
A list of grants.
-
#next_marker ⇒ String
When
Truncatedis true, this element is present and contains the value to use for theMarkerparameter in a subsequent request. -
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list.
Instance Attribute Details
#grants ⇒ Array<Types::GrantListEntry>
A list of grants.
5035 5036 5037 5038 5039 5040 5041 |
# File 'lib/aws-sdk-kms/types.rb', line 5035 class ListGrantsResponse < Struct.new( :grants, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
When Truncated is true, this element is present and contains the
value to use for the Marker parameter in a subsequent request.
5035 5036 5037 5038 5039 5040 5041 |
# File 'lib/aws-sdk-kms/types.rb', line 5035 class ListGrantsResponse < Struct.new( :grants, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |
#truncated ⇒ Boolean
A flag that indicates whether there are more items in the list. When
this value is true, the list in this response is truncated. To get
more items, pass the value of the NextMarker element in this
response to the Marker parameter in a subsequent request.
5035 5036 5037 5038 5039 5040 5041 |
# File 'lib/aws-sdk-kms/types.rb', line 5035 class ListGrantsResponse < Struct.new( :grants, :next_marker, :truncated) SENSITIVE = [] include Aws::Structure end |