Class: Aws::KMS::Types::XksProxyVpcEndpointServiceInUseException
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::XksProxyVpcEndpointServiceInUseException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
The request was rejected because the specified Amazon VPC endpoint service is already associated with another external key store in this Amazon Web Services Region. Each external key store in a Region must use a different Amazon VPC endpoint service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7486 7487 7488 7489 7490 |
# File 'lib/aws-sdk-kms/types.rb', line 7486 class XksProxyVpcEndpointServiceInUseException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |