Class: Aws::KMS::Types::XksProxyVpcEndpointServiceInvalidConfigurationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::KMS::Types::XksProxyVpcEndpointServiceInvalidConfigurationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kms/types.rb
Overview
The request was rejected because the Amazon VPC endpoint service configuration does not fulfill the requirements for an external key store. To identify the cause, see the error message that accompanies the exception and [review the requirements] for Amazon VPC endpoint service connectivity for an external key store.
[1]: docs.aws.amazon.com/kms/latest/developerguide/vpc-connectivity.html#xks-vpc-requirements
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
7632 7633 7634 7635 7636 |
# File 'lib/aws-sdk-kms/types.rb', line 7632 class XksProxyVpcEndpointServiceInvalidConfigurationException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |